@@ -1,11 +1,10 @@
-import { Indexer } from "@cronos-so/indexer";
 import { Program, Provider } from "@project-serum/anchor";
 import { Account } from "./account";
 import { Instruction } from "./instruction";
 import { IDL, Cronos as _Cronos } from "./idl";
 
 export class Cronos {
-  static DEVNET_PROGRAM_ID = "9cEqpQLV3VGN6mBtFKwheJoreg6BXvyCf6pWWDA1FhRf";
+  static DEVNET_PROGRAM_ID = "EikDpw2iRwqMrDwGBxAdbdfVAURkvDajZLWrFoYc2dc5";
   static MAINNET_PROGRAM_ID = "";
 
   public account: Account;
@@ -14,14 +13,8 @@ export class Cronos {
 
   constructor(provider: Provider, programId: string) {
     const cronos = new Program(IDL, programId, provider);
-    const indexer = new Indexer(
-      provider,
-      programId === Cronos.MAINNET_PROGRAM_ID
-        ? Indexer.MAINNET_PROGRAM_ID
-        : Indexer.DEVNET_PROGRAM_ID
-    );
     const account = new Account(cronos);
-    const instruction = new Instruction(account, cronos, indexer);
+    const instruction = new Instruction(account, cronos);
     this.account = account;
     this.instruction = instruction;
     this.programId = programId;
